@@ -4,15 +4,24 @@ use gitql_core::environment::Environment;
 use gitql_core::types::DataType;
 use gitql_core::value::Value;
 
+use crate::operator::ArithmeticOperator;
+use crate::operator::BitwiseOperator;
+use crate::operator::ComparisonOperator;
+use crate::operator::LogicalOperator;
+use crate::operator::PrefixUnaryOperator;
+
 #[derive(PartialEq)]
 pub enum ExpressionKind {
     Assignment,
     String,
     Symbol,
+    Array,
     GlobalVariable,
     Number,
     Boolean,
     PrefixUnary,
+    Index,
+    Slice,
     Arithmetic,
     Comparison,
     Like,
@@ -125,6 +134,25 @@ impl Expression for SymbolExpression {
     }
 }
 
+pub struct ArrayExpression {
+    pub values: Vec<Box<dyn Expression>>,
+    pub element_type: DataType,
+}
+
+impl Expression for ArrayExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Array
+    }
+
+    fn expr_type(&self, _scope: &Environment) -> DataType {
+        DataType::Array(Box::new(self.element_type.clone()))
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+}
+
 pub struct GlobalVariableExpression {
     pub name: String,
 }
@@ -182,12 +210,6 @@ impl Expression for BooleanExpression {
     }
 }
 
-#[derive(PartialEq)]
-pub enum PrefixUnaryOperator {
-    Minus,
-    Bang,
-}
-
 pub struct PrefixUnary {
     pub right: Box<dyn Expression>,
     pub op: PrefixUnaryOperator,
@@ -211,13 +233,44 @@ impl Expression for PrefixUnary {
     }
 }
 
-#[derive(PartialEq)]
-pub enum ArithmeticOperator {
-    Plus,
-    Minus,
-    Star,
-    Slash,
-    Modulus,
+pub struct IndexExpression {
+    pub collection: Box<dyn Expression>,
+    pub element_type: DataType,
+    pub index: Box<dyn Expression>,
+}
+
+impl Expression for IndexExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Index
+    }
+
+    fn expr_type(&self, _scope: &Environment) -> DataType {
+        self.element_type.clone()
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+}
+
+pub struct SliceExpression {
+    pub collection: Box<dyn Expression>,
+    pub start: Option<Box<dyn Expression>>,
+    pub end: Option<Box<dyn Expression>>,
+}
+
+impl Expression for SliceExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Slice
+    }
+
+    fn expr_type(&self, scope: &Environment) -> DataType {
+        self.collection.expr_type(scope)
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
 }
 
 pub struct ArithmeticExpression {
@@ -243,17 +296,6 @@ impl Expression for ArithmeticExpression {
     }
 }
 
-#[derive(PartialEq)]
-pub enum ComparisonOperator {
-    Greater,
-    GreaterEqual,
-    Less,
-    LessEqual,
-    Equal,
-    NotEqual,
-    NullSafeEqual,
-}
-
 pub struct ComparisonExpression {
     pub left: Box<dyn Expression>,
     pub operator: ComparisonOperator,
@@ -335,13 +377,6 @@ impl Expression for GlobExpression {
     }
 }
 
-#[derive(PartialEq)]
-pub enum LogicalOperator {
-    Or,
-    And,
-    Xor,
-}
-
 pub struct LogicalExpression {
     pub left: Box<dyn Expression>,
     pub operator: LogicalOperator,
@@ -362,14 +397,6 @@ impl Expression for LogicalExpression {
     }
 }
 
-#[derive(PartialEq)]
-pub enum BitwiseOperator {
-    Or,
-    And,
-    RightShift,
-    LeftShift,
-}
-
 pub struct BitwiseExpression {
     pub left: Box<dyn Expression>,
     pub operator: BitwiseOperator,
