@@ -40,7 +40,12 @@ pub fn render_objects(
 
     // Print all data without pagination
     if !pagination || page_size >= gql_group_len {
-        print_group_as_table(&titles, table_headers, &gql_group.rows);
+        print_group_as_table(
+            &titles,
+            table_headers,
+            &gql_group.rows,
+            hidden_selections.len(),
+        );
         return;
     }
 
@@ -54,7 +59,12 @@ pub fn render_objects(
 
         let current_page_groups = &gql_group.rows[start_index..end_index];
         println!("Page {}/{}", current_page, number_of_pages);
-        print_group_as_table(&titles, table_headers.clone(), current_page_groups);
+        print_group_as_table(
+            &titles,
+            table_headers.clone(),
+            current_page_groups,
+            hidden_selections.len(),
+        );
 
         let pagination_input = handle_pagination_input(current_page, number_of_pages);
         match pagination_input {
@@ -65,7 +75,12 @@ pub fn render_objects(
     }
 }
 
-fn print_group_as_table(titles: &[&str], table_headers: Vec<comfy_table::Cell>, rows: &[Row]) {
+fn print_group_as_table(
+    titles: &[&str],
+    table_headers: Vec<comfy_table::Cell>,
+    rows: &[Row],
+    hidden_selection_count: usize,
+) {
     let mut table = comfy_table::Table::new();
 
     // Setup table style
@@ -81,7 +96,7 @@ fn print_group_as_table(titles: &[&str], table_headers: Vec<comfy_table::Cell>,
     for row in rows {
         let mut table_row: Vec<comfy_table::Cell> = vec![];
         for index in 0..titles_len {
-            let value = row.values.get(index).unwrap();
+            let value = row.values.get(index + hidden_selection_count).unwrap();
             table_row.push(comfy_table::Cell::new(value.to_string()));
         }
         table.add_row(table_row);
