@@ -1,31 +1,35 @@
 use gitql_ast::expression::ArithmeticExpression;
-use gitql_ast::expression::ArithmeticOperator;
+use gitql_ast::expression::ArrayExpression;
 use gitql_ast::expression::AssignmentExpression;
 use gitql_ast::expression::BetweenExpression;
 use gitql_ast::expression::BitwiseExpression;
-use gitql_ast::expression::BitwiseOperator;
 use gitql_ast::expression::BooleanExpression;
 use gitql_ast::expression::CallExpression;
 use gitql_ast::expression::CaseExpression;
 use gitql_ast::expression::ComparisonExpression;
-use gitql_ast::expression::ComparisonOperator;
 use gitql_ast::expression::Expression;
 use gitql_ast::expression::ExpressionKind::*;
 use gitql_ast::expression::GlobExpression;
 use gitql_ast::expression::GlobalVariableExpression;
 use gitql_ast::expression::InExpression;
+use gitql_ast::expression::IndexExpression;
 use gitql_ast::expression::IsNullExpression;
 use gitql_ast::expression::LikeExpression;
 use gitql_ast::expression::LogicalExpression;
-use gitql_ast::expression::LogicalOperator;
 use gitql_ast::expression::NumberExpression;
 use gitql_ast::expression::PrefixUnary;
-use gitql_ast::expression::PrefixUnaryOperator;
 use gitql_ast::expression::RegexExpression;
+use gitql_ast::expression::SliceExpression;
 use gitql_ast::expression::StringExpression;
 use gitql_ast::expression::StringValueType;
 use gitql_ast::expression::SymbolExpression;
+use gitql_ast::operator::ArithmeticOperator;
+use gitql_ast::operator::BitwiseOperator;
+use gitql_ast::operator::ComparisonOperator;
+use gitql_ast::operator::LogicalOperator;
+use gitql_ast::operator::PrefixUnaryOperator;
 use gitql_core::environment::Environment;
+use gitql_core::types::DataType;
 use gitql_core::value::Value;
 
 use regex::Regex;
@@ -60,6 +64,13 @@ pub fn evaluate_expression(
                 .unwrap();
             evaluate_symbol(expr, titles, object)
         }
+        Array => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<ArrayExpression>()
+                .unwrap();
+            evaluate_array(env, expr, titles, object)
+        }
         GlobalVariable => {
             let expr = expression
                 .as_any()
@@ -85,6 +96,20 @@ pub fn evaluate_expression(
             let expr = expression.as_any().downcast_ref::<PrefixUnary>().unwrap();
             evaluate_prefix_unary(env, expr, titles, object)
         }
+        Index => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<IndexExpression>()
+                .unwrap();
+            evaluate_collection_index(env, expr, titles, object)
+        }
+        Slice => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<SliceExpression>()
+                .unwrap();
+            evaluate_collection_slice(env, expr, titles, object)
+        }
         Arithmetic => {
             let expr = expression
                 .as_any()
@@ -229,6 +254,20 @@ fn evaluate_symbol(
     Err(format!("Invalid column name `{}`", &expr.value))
 }
 
+fn evaluate_array(
+    env: &mut Environment,
+    expr: &ArrayExpression,
+    titles: &[String],
+    object: &Vec<Value>,
+) -> Result<Value, String> {
+    let data_type = &expr.element_type;
+    let mut values: Vec<Value> = Vec::with_capacity(expr.values.len());
+    for value in &expr.values {
+        values.push(evaluate_expression(env, value, titles, object)?);
+    }
+    Ok(Value::Array(data_type.clone(), values))
+}
+
 fn evaluate_global_variable(
     env: &mut Environment,
     expr: &GlobalVariableExpression,
@@ -252,6 +291,78 @@ fn evaluate_boolean(expr: &BooleanExpression) -> Result<Value, String> {
     Ok(Value::Boolean(expr.is_true))
 }
 
+fn evaluate_collection_index(
+    env: &mut Environment,
+    expr: &IndexExpression,
+    titles: &[String],
+    object: &Vec<Value>,
+) -> Result<Value, String> {
+    let array = evaluate_expression(env, &expr.collection, titles, object)?;
+    let index = evaluate_expression(env, &expr.index, titles, object)?;
+
+    let elements = array.as_array();
+    let position = index.as_int() - 1;
+
+    if position < 0 {
+        return Err("Array position must be larger than or equal 1".to_string());
+    }
+
+    if position as usize >= elements.len() {
+        return Err(format!(
+            "Array position is larger than array length {} and {}",
+            position + 1,
+            elements.len()
+        ));
+    }
+
+    Ok(elements[position as usize].clone())
+}
+
+fn evaluate_collection_slice(
+    env: &mut Environment,
+    expr: &SliceExpression,
+    titles: &[String],
+    object: &Vec<Value>,
+) -> Result<Value, String> {
+    let array = evaluate_expression(env, &expr.collection, titles, object)?;
+    let elements = array.as_array();
+    let len = elements.len() as i64;
+
+    let start = if let Some(start_expr) = &expr.start {
+        evaluate_expression(env, start_expr, titles, object)?.as_int()
+    } else {
+        1
+    };
+
+    if start < 1 || start >= len {
+        return Err("Slice start must be between 1 and length of collection".to_string());
+    }
+
+    let end = if let Some(end_expr) = &expr.end {
+        evaluate_expression(env, end_expr, titles, object)?.as_int()
+    } else {
+        len
+    };
+
+    if end < 1 || end > len {
+        return Err("Slice end must be between 1 and length of collection".to_string());
+    }
+
+    if start > end {
+        return Err("Slice end must be larger then start".to_string());
+    }
+
+    let usize_start = (start - 1) as usize;
+    let usize_end: usize = (end) as usize;
+    let slice: Vec<Value> = elements[usize_start..usize_end].to_vec();
+    let element_type = match expr.expr_type(env) {
+        DataType::Array(element_type) => *element_type,
+        _ => DataType::Any,
+    };
+
+    Ok(Value::Array(element_type, slice))
+}
+
 fn evaluate_prefix_unary(
     env: &mut Environment,
     expr: &PrefixUnary,
