@@ -4,6 +4,7 @@ use std::collections::HashMap;
 
 use gitql_ast::statement::AggregateValue;
 use gitql_ast::statement::AggregationsStatement;
+use gitql_ast::statement::DoStatement;
 use gitql_ast::statement::GlobalVariableStatement;
 use gitql_ast::statement::GroupByStatement;
 use gitql_ast::statement::HavingStatement;
@@ -34,20 +35,20 @@ pub fn execute_statement(
     hidden_selection: &Vec<String>,
 ) -> Result<(), String> {
     match statement.kind() {
+        Do => {
+            let statement = statement.as_any().downcast_ref::<DoStatement>().unwrap();
+            execute_do_statement(env, statement, gitql_object)
+        }
         Select => {
             let statement = statement
                 .as_any()
                 .downcast_ref::<SelectStatement>()
                 .unwrap();
 
-            // Copy alias table to be last later for Aggregations functions
-            for alias in &statement.alias_table {
-                alias_table.insert(alias.0.to_string(), alias.1.to_string());
-            }
-
             execute_select_statement(
                 env,
                 statement,
+                alias_table,
                 data_provider,
                 gitql_object,
                 hidden_selection,
@@ -106,20 +107,34 @@ pub fn execute_statement(
     }
 }
 
+fn execute_do_statement(
+    env: &mut Environment,
+    statement: &DoStatement,
+    gitql_object: &mut GitQLObject,
+) -> Result<(), String> {
+    let row_values = &gitql_object.groups[0].rows[0].values;
+    evaluate_expression(env, &statement.expression, &gitql_object.titles, row_values)?;
+    Ok(())
+}
+
 #[allow(clippy::borrowed_box)]
 fn execute_select_statement(
     env: &mut Environment,
     statement: &SelectStatement,
+    alias_table: &HashMap<String, String>,
     data_provider: &Box<dyn DataProvider>,
     gitql_object: &mut GitQLObject,
     hidden_selections: &Vec<String>,
 ) -> Result<(), String> {
     // Append hidden selection to the selected fields names
     let mut fields_names = statement.fields_names.to_owned();
+    let mut hidden_selection_count = 0;
+
     if !statement.table_name.is_empty() {
         for hidden in hidden_selections {
             if !fields_names.contains(hidden) {
-                fields_names.push(hidden.to_string());
+                fields_names.insert(0, hidden.to_string());
+                hidden_selection_count += 1;
             }
         }
     }
@@ -128,7 +143,7 @@ fn execute_select_statement(
     for field_name in &fields_names {
         gitql_object
             .titles
-            .push(get_column_name(&statement.alias_table, field_name));
+            .push(get_column_name(alias_table, field_name));
     }
 
     // Select objects from the target table
@@ -138,7 +153,8 @@ fn execute_select_statement(
         &fields_names,
         &gitql_object.titles,
         &statement.fields_values,
-    );
+        hidden_selection_count,
+    )?;
 
     gitql_object.groups.append(&mut provided_object.groups);
     Ok(())
