@@ -1,10 +1,24 @@
-use gitql_core::environment::Environment;
-use gitql_core::value::Value;
 use std::collections::HashMap;
 use std::num::IntErrorKind;
 use std::num::ParseIntError;
 use std::vec;
 
+use gitql_ast::expression::ArithmeticExpression;
+use gitql_ast::expression::ArrayExpression;
+use gitql_ast::expression::AssignmentExpression;
+use gitql_ast::expression::BetweenExpression;
+use gitql_ast::expression::BitwiseExpression;
+use gitql_ast::expression::*;
+use gitql_ast::operator::ArithmeticOperator;
+use gitql_ast::operator::BitwiseOperator;
+use gitql_ast::operator::ComparisonOperator;
+use gitql_ast::operator::LogicalOperator;
+use gitql_ast::operator::PrefixUnaryOperator;
+use gitql_ast::statement::*;
+use gitql_core::environment::Environment;
+use gitql_core::types::DataType;
+use gitql_core::value::Value;
+
 use crate::context::ParserContext;
 use crate::diagnostic::Diagnostic;
 use crate::tokenizer::Location;
@@ -13,17 +27,16 @@ use crate::tokenizer::TokenKind;
 use crate::type_checker::are_types_equals;
 use crate::type_checker::check_all_values_are_same_type;
 use crate::type_checker::check_function_call_arguments;
+use crate::type_checker::resolve_call_expression_return_type;
+use crate::type_checker::type_check_projection_symbols;
 use crate::type_checker::type_check_selected_fields;
 use crate::type_checker::TypeCheckResult;
 
-use gitql_ast::expression::*;
-use gitql_ast::statement::*;
-use gitql_core::types::DataType;
-
 pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box<Diagnostic>> {
     let mut position = 0;
     let first_token = &tokens[position];
     let query_result = match &first_token.kind {
+        TokenKind::Do => parse_do_query(env, &tokens, &mut position),
         TokenKind::Set => parse_set_query(env, &tokens, &mut position),
         TokenKind::Select => parse_select_query(env, &tokens, &mut position),
         TokenKind::Describe => parse_describe_query(env, &tokens, &mut position),
@@ -50,6 +63,27 @@ pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box
     query_result
 }
 
+fn parse_do_query(
+    env: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Query, Box<Diagnostic>> {
+    // Consume Do keyword
+    *position += 1;
+
+    if *position >= tokens.len() {
+        return Err(
+            Diagnostic::error("Expect expression after Do Statement keyword")
+                .with_location(get_safe_location(tokens, *position - 1))
+                .as_boxed(),
+        );
+    }
+
+    let mut context = ParserContext::default();
+    let expression = parse_expression(&mut context, env, tokens, position)?;
+    Ok(Query::Do(DoStatement { expression }))
+}
+
 fn parse_set_query(
     env: &mut Environment,
     tokens: &[Token],
@@ -176,6 +210,7 @@ fn parse_select_query(
                 let statement = parse_select_statement(&mut context, env, tokens, position)?;
                 statements.insert("select", statement);
                 context.is_single_value_query = !context.aggregations.is_empty();
+                context.has_select_statement = true;
             }
             TokenKind::Where => {
                 if statements.contains_key("where") {
@@ -341,11 +376,19 @@ fn parse_select_query(
         .cloned()
         .collect();
 
+    type_check_projection_symbols(
+        env,
+        &context.table_name,
+        &context.projection_names,
+        &context.projection_locations,
+    )?;
+
     Ok(Query::Select(GQLQuery {
         statements,
         has_aggregation_function: context.is_single_value_query,
         has_group_by_statement: context.has_group_by_statement,
         hidden_selections,
+        alias_table: context.name_alias_table,
     }))
 }
 
@@ -369,7 +412,6 @@ fn parse_select_statement(
     let mut table_name = "";
     let mut fields_names: Vec<String> = Vec::new();
     let mut fields_values: Vec<Box<dyn Expression>> = Vec::new();
-    let mut alias_table: HashMap<String, String> = HashMap::new();
     let mut is_select_all = false;
     let mut is_distinct = false;
 
@@ -416,7 +458,7 @@ fn parse_select_statement(
                 // Register alias name
                 let alias_name = alias_name_token.ok().unwrap().literal.to_string();
                 if context.selected_fields.contains(&alias_name)
-                    || alias_table.contains_key(&alias_name)
+                    || context.name_alias_table.contains_key(&alias_name)
                 {
                     return Err(
                         Diagnostic::error("You already have field with the same name")
@@ -433,7 +475,9 @@ fn parse_select_statement(
                 env.define(alias_name.to_string(), expr_type.clone());
 
                 context.selected_fields.push(alias_name.clone());
-                alias_table.insert(field_name.to_string(), alias_name);
+                context
+                    .name_alias_table
+                    .insert(field_name.to_string(), alias_name.to_string());
             }
 
             // Register field type
@@ -475,6 +519,7 @@ fn parse_select_statement(
 
         // Consume table name
         *position += 1;
+        context.table_name = table_name.to_string();
 
         register_current_table_fields_types(env, table_name);
     }
@@ -521,7 +566,6 @@ fn parse_select_statement(
         table_name: table_name.to_string(),
         fields_names,
         fields_values,
-        alias_table,
         is_distinct,
     }))
 }
@@ -1620,7 +1664,7 @@ fn parse_glob_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_unary_expression(context, env, tokens, position);
+    let expression = parse_index_or_slice_expression(context, env, tokens, position);
     if expression.is_err() || *position >= tokens.len() {
         return expression;
     }
@@ -1639,7 +1683,7 @@ fn parse_glob_expression(
             .as_boxed());
         }
 
-        let pattern = parse_unary_expression(context, env, tokens, position)?;
+        let pattern = parse_index_or_slice_expression(context, env, tokens, position)?;
         if !pattern.expr_type(env).is_text() {
             return Err(Diagnostic::error(&format!(
                 "Expect `GLOB` right hand side to be `TEXT` but got {}",
@@ -1658,6 +1702,166 @@ fn parse_glob_expression(
     Ok(lhs)
 }
 
+fn parse_index_or_slice_expression(
+    context: &mut ParserContext,
+    env: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    let mut expression = parse_unary_expression(context, env, tokens, position)?;
+
+    while *position < tokens.len() && tokens[*position].kind == TokenKind::LeftBracket {
+        // Consume Left Bracket `[`
+        *position += 1;
+
+        let expression_type = expression.expr_type(env);
+
+        if !expression_type.is_array() {
+            return Err(
+                Diagnostic::error("Expect Right side of index expression to be Array")
+                    .with_location(get_safe_location(tokens, *position))
+                    .as_boxed(),
+            );
+        }
+
+        // Make sure right hand side is an Array
+        let rhs_type = expression.expr_type(env);
+        if !rhs_type.is_array() {
+            return Err(Diagnostic::error(&format!(
+                "Expect right side of index expression to be Array but got {}",
+                rhs_type
+            ))
+            .with_location(get_safe_location(tokens, *position))
+            .as_boxed());
+        }
+
+        // Slice with end only range [:end]
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::Colon {
+            // Consume Colon `:`
+            *position += 1;
+
+            let slice_end = parse_unary_expression(context, env, tokens, position)?;
+            let end_type = slice_end.expr_type(env);
+            if !end_type.is_int() {
+                return Err(Diagnostic::error(&format!(
+                    "Expect Slice expression end value to be Int but got {}",
+                    end_type
+                ))
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+            }
+
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::RightBracket {
+                // Consume Right Bracket `]`
+                *position += 1;
+            } else {
+                return Err(Diagnostic::error("Expect `]` After Slice expression")
+                    .with_location(get_safe_location(tokens, *position))
+                    .as_boxed());
+            }
+
+            expression = Box::new(SliceExpression {
+                collection: expression,
+                start: None,
+                end: Some(slice_end),
+            });
+            continue;
+        }
+
+        let index = parse_unary_expression(context, env, tokens, position)?;
+
+        // Slice Expression with Start and End range [start:end]
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::Colon {
+            // Consume Colon `:`
+            *position += 1;
+
+            let start_type = index.expr_type(env);
+            if !start_type.is_int() {
+                return Err(Diagnostic::error(&format!(
+                    "Expect Slice expression start value to be Int but got {}",
+                    start_type
+                ))
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+            }
+
+            // Slice with start only range [start:]
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::RightBracket {
+                // Consume Right Bracket `]`
+                *position += 1;
+
+                expression = Box::new(SliceExpression {
+                    collection: expression,
+                    start: Some(index),
+                    end: None,
+                });
+                continue;
+            }
+
+            let slice_end = parse_unary_expression(context, env, tokens, position)?;
+            let end_type = slice_end.expr_type(env);
+            if !end_type.is_int() {
+                return Err(Diagnostic::error(&format!(
+                    "Expect Slice expression end value to be Int but got {}",
+                    end_type
+                ))
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+            }
+
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::RightBracket {
+                // Consume Right Bracket `]`
+                *position += 1;
+            } else {
+                return Err(Diagnostic::error("Expect `]` After Slice expression")
+                    .with_location(get_safe_location(tokens, *position))
+                    .as_boxed());
+            }
+
+            expression = Box::new(SliceExpression {
+                collection: expression,
+                start: Some(index),
+                end: Some(slice_end),
+            });
+            continue;
+        }
+
+        // Index Expression
+        // Make sure index is integer type
+        let index_type = index.expr_type(env);
+        if !index_type.is_int() {
+            return Err(Diagnostic::error(&format!(
+                "Expect Index value to be Int but got {}",
+                index_type
+            ))
+            .with_location(get_safe_location(tokens, *position))
+            .as_boxed());
+        }
+
+        let array_element_type = match expression_type {
+            DataType::Array(element_type) => *element_type,
+            _ => DataType::Any,
+        };
+
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::RightBracket {
+            // Consume Left Right `]`
+            *position += 1;
+        } else {
+            return Err(Diagnostic::error("Expect `]` after index expression")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+        }
+
+        expression = Box::new(IndexExpression {
+            collection: expression,
+            element_type: array_element_type,
+            index,
+        });
+    }
+
+    Ok(expression)
+}
+
 fn parse_unary_expression(
     context: &mut ParserContext,
     env: &mut Environment,
@@ -1703,105 +1907,93 @@ fn parse_function_call_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_primary_expression(context, env, tokens, position)?;
-    if *position < tokens.len() && tokens[*position].kind == TokenKind::LeftParen {
-        let symbol_expression = expression.as_any().downcast_ref::<SymbolExpression>();
-        let function_name_location = get_safe_location(tokens, *position);
+    if *position < tokens.len() && tokens[*position].kind == TokenKind::Symbol {
+        let symbol_token = &tokens[*position];
+        if *position + 1 < tokens.len() && tokens[*position + 1].kind == TokenKind::LeftParen {
+            let function_name = &symbol_token.literal;
+            let function_name_location = symbol_token.location;
 
-        // Make sure function name is SymbolExpression
-        if symbol_expression.is_none() {
-            return Err(Diagnostic::error("Function name must be an identifier")
+            // Consume function name
+            *position += 1;
+
+            // Check if this function is a Standard library functions
+            if env.is_std_function(function_name.as_str()) {
+                let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
+                let signature = env.std_signature(function_name.as_str()).unwrap();
+
+                check_function_call_arguments(
+                    env,
+                    &mut arguments,
+                    &signature.parameters,
+                    function_name.to_string(),
+                    function_name_location,
+                )?;
+
+                // Register function name with return type
+                let return_type = resolve_call_expression_return_type(env, signature, &arguments);
+                env.define(function_name.to_string(), return_type.clone());
+
+                return Ok(Box::new(CallExpression {
+                    function_name: function_name.to_string(),
+                    arguments,
+                    return_type,
+                }));
+            }
+
+            // Check if this function is an Aggregation functions
+            if env.is_aggregation_function(function_name.as_str()) {
+                let aggregations_count_before = context.aggregations.len();
+                let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
+                let has_aggregations = context.aggregations.len() != aggregations_count_before;
+
+                // Prevent calling aggregation function with aggregation values as argument
+                if has_aggregations {
+                    return Err(Diagnostic::error(
+                        "Aggregated values can't as used for aggregation function argument",
+                    )
+                    .with_location(function_name_location)
+                    .as_boxed());
+                }
+
+                let signature = env.aggregation_signature(function_name.as_str()).unwrap();
+
+                // Perform type checking and implicit casting if needed for function arguments
+                check_function_call_arguments(
+                    env,
+                    &mut arguments,
+                    &signature.parameters,
+                    function_name.to_string(),
+                    function_name_location,
+                )?;
+
+                let column_name = context.generate_column_name();
+                context.hidden_selections.push(column_name.to_string());
+
+                // Register aggregation generated name with return type
+                let return_type = resolve_call_expression_return_type(env, signature, &arguments);
+                env.define(column_name.to_string(), return_type);
+
+                context.aggregations.insert(
+                    column_name.clone(),
+                    AggregateValue::Function(function_name.to_string(), arguments),
+                );
+
+                // Return a Symbol that reference to the aggregation function generated name
+                return Ok(Box::new(SymbolExpression { value: column_name }));
+            }
+
+            // Report that this function name is not standard or aggregation
+            return Err(Diagnostic::error("No such function name")
+                .add_help(&format!(
+                    "Function `{}` is not an Aggregation or Standard library function name",
+                    function_name,
+                ))
                 .with_location(function_name_location)
                 .as_boxed());
         }
-
-        let function_name = &symbol_expression.unwrap().value;
-
-        // Check if this function is a Standard library functions
-        if env.is_std_function(function_name.as_str()) {
-            let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
-            let prototype = env.std_signature(function_name.as_str()).unwrap();
-            let parameters = &prototype.parameters;
-            let mut return_type = prototype.return_type.clone();
-            if let DataType::Dynamic(calculate_type) = return_type {
-                return_type = calculate_type(parameters);
-            }
-
-            check_function_call_arguments(
-                env,
-                &mut arguments,
-                parameters,
-                function_name.to_string(),
-                function_name_location,
-            )?;
-
-            // Register function name with return type
-            env.define(function_name.to_string(), return_type.clone());
-
-            return Ok(Box::new(CallExpression {
-                function_name: function_name.to_string(),
-                arguments,
-                return_type,
-            }));
-        }
-
-        // Check if this function is an Aggregation functions
-        if env.is_aggregation_function(function_name.as_str()) {
-            let aggregations_count_before = context.aggregations.len();
-            let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
-            let has_aggregations = context.aggregations.len() != aggregations_count_before;
-
-            // Prevent calling aggregation function with aggregation values as argument
-            if has_aggregations {
-                return Err(Diagnostic::error(
-                    "Aggregated values can't as used for aggregation function argument",
-                )
-                .with_location(function_name_location)
-                .as_boxed());
-            }
-
-            let prototype = env.aggregation_signature(function_name.as_str()).unwrap();
-
-            let parameters = &prototype.parameters.clone();
-            let mut return_type = prototype.return_type.clone();
-            if let DataType::Dynamic(calculate_type) = return_type {
-                return_type = calculate_type(parameters);
-            }
-
-            // Perform type checking and implicit casting if needed for function arguments
-            check_function_call_arguments(
-                env,
-                &mut arguments,
-                parameters,
-                function_name.to_string(),
-                function_name_location,
-            )?;
-
-            let column_name = context.generate_column_name();
-            context.hidden_selections.push(column_name.to_string());
-
-            // Register aggregation generated name with return type
-            env.define(column_name.to_string(), return_type);
-
-            context.aggregations.insert(
-                column_name.clone(),
-                AggregateValue::Function(function_name.to_string(), arguments),
-            );
-
-            // Return a Symbol that reference to the aggregation function generated name
-            return Ok(Box::new(SymbolExpression { value: column_name }));
-        }
-
-        // Report that this function name is not standard or aggregation
-        return Err(Diagnostic::error("No such function name")
-            .add_help(&format!(
-                "Function `{}` is not an Aggregation or Standard library function name",
-                function_name,
-            ))
-            .with_location(function_name_location)
-            .as_boxed());
     }
-    Ok(expression)
+
+    parse_primary_expression(context, env, tokens, position)
 }
 
 fn parse_arguments_expressions(
@@ -1856,6 +2048,13 @@ fn parse_primary_expression(
     }
 
     match tokens[*position].kind {
+        TokenKind::Integer => parse_const_integer_expression(tokens, position),
+        TokenKind::Float => parse_const_float_expression(tokens, position),
+        TokenKind::Symbol => parse_symbol_expression(context, env, tokens, position),
+        TokenKind::Array => parse_array_value_expression(context, env, tokens, position),
+        TokenKind::LeftBracket => parse_array_value_expression(context, env, tokens, position),
+        TokenKind::LeftParen => parse_group_expression(context, env, tokens, position),
+        TokenKind::Case => parse_case_expression(context, env, tokens, position),
         TokenKind::String => {
             *position += 1;
             Ok(Box::new(StringExpression {
@@ -1863,53 +2062,11 @@ fn parse_primary_expression(
                 value_type: StringValueType::Text,
             }))
         }
-        TokenKind::Symbol => {
-            let value = tokens[*position].literal.to_string();
-            *position += 1;
-            if !context.selected_fields.contains(&value) {
-                context.hidden_selections.push(value.to_string());
-            }
-            Ok(Box::new(SymbolExpression { value }))
-        }
         TokenKind::GlobalVariable => {
             let name = tokens[*position].literal.to_string();
             *position += 1;
             Ok(Box::new(GlobalVariableExpression { name }))
         }
-        TokenKind::Integer => {
-            if let Ok(integer) = tokens[*position].literal.parse::<i64>() {
-                *position += 1;
-                let value = Value::Integer(integer);
-                return Ok(Box::new(NumberExpression { value }));
-            }
-
-            Err(Diagnostic::error("Too big Integer value")
-                .add_help("Try to use smaller value")
-                .add_note(&format!(
-                    "Integer value must be between {} and {}",
-                    i64::MIN,
-                    i64::MAX
-                ))
-                .with_location(tokens[*position].location)
-                .as_boxed())
-        }
-        TokenKind::Float => {
-            if let Ok(float) = tokens[*position].literal.parse::<f64>() {
-                *position += 1;
-                let value = Value::Float(float);
-                return Ok(Box::new(NumberExpression { value }));
-            }
-
-            Err(Diagnostic::error("Too big Float value")
-                .add_help("Try to use smaller value")
-                .add_note(&format!(
-                    "Float value must be between {} and {}",
-                    f64::MIN,
-                    f64::MAX
-                ))
-                .with_location(tokens[*position].location)
-                .as_boxed())
-        }
         TokenKind::True => {
             *position += 1;
             Ok(Box::new(BooleanExpression { is_true: true }))
@@ -1922,12 +2079,154 @@ fn parse_primary_expression(
             *position += 1;
             Ok(Box::new(NullExpression {}))
         }
-        TokenKind::LeftParen => parse_group_expression(context, env, tokens, position),
-        TokenKind::Case => parse_case_expression(context, env, tokens, position),
         _ => Err(un_expected_expression_error(tokens, position)),
     }
 }
 
+fn parse_const_integer_expression(
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    if let Ok(integer) = tokens[*position].literal.parse::<i64>() {
+        *position += 1;
+        let value = Value::Integer(integer);
+        return Ok(Box::new(NumberExpression { value }));
+    }
+
+    Err(Diagnostic::error("Too big Integer value")
+        .add_help("Try to use smaller value")
+        .add_note(&format!(
+            "Integer value must be between {} and {}",
+            i64::MIN,
+            i64::MAX
+        ))
+        .with_location(tokens[*position].location)
+        .as_boxed())
+}
+
+fn parse_const_float_expression(
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    if let Ok(float) = tokens[*position].literal.parse::<f64>() {
+        *position += 1;
+        let value = Value::Float(float);
+        return Ok(Box::new(NumberExpression { value }));
+    }
+
+    Err(Diagnostic::error("Too big Float value")
+        .add_help("Try to use smaller value")
+        .add_note(&format!(
+            "Float value must be between {} and {}",
+            f64::MIN,
+            f64::MAX
+        ))
+        .with_location(tokens[*position].location)
+        .as_boxed())
+}
+
+fn parse_symbol_expression(
+    context: &mut ParserContext,
+    env: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    let mut value = tokens[*position].literal.to_string();
+    let location = tokens[*position].location;
+
+    // Collect projections only inside select statement
+    if !context.has_select_statement {
+        context.projection_names.push(value.to_string());
+        context.projection_locations.push(location);
+    }
+
+    *position += 1;
+
+    if context.has_select_statement {
+        // Replace name by alias if it used after select statement
+        // This workaround will help to execute query like
+        // SELECT commit_count as cc from branches where commit_count > 1
+        if context.name_alias_table.contains_key(&value) {
+            value = context.name_alias_table[&value].to_string();
+        }
+
+        if !env.scopes.contains_key(&value) {
+            return Err(Diagnostic::error("Unresolved column or variable name")
+                .add_help("Please check schema from docs website or SHOW query")
+                .with_location(tokens[*position].location)
+                .as_boxed());
+        }
+
+        if !context.selected_fields.contains(&value) {
+            context.hidden_selections.push(value.to_string());
+        }
+    }
+
+    Ok(Box::new(SymbolExpression { value }))
+}
+
+fn parse_array_value_expression(
+    context: &mut ParserContext,
+    env: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
+    // Consume the Optional Array keyword
+    if *position < tokens.len() && tokens[*position].kind == TokenKind::Array {
+        // Consume Array keyword
+        *position += 1;
+
+        // Make sure Array keyword followed by [
+        if *position >= tokens.len() || tokens[*position].kind != TokenKind::LeftBracket {
+            return Err(Diagnostic::error("Expect `[` after `ARRAY` keyword")
+                .with_location(get_safe_location(tokens, *position))
+                .add_help("Try to add '[' after `ARRAY` keyword")
+                .as_boxed());
+        }
+    }
+
+    // Consume Left Bracket `[`
+    *position += 1;
+
+    // Parse array values
+    let mut array_values: Vec<Box<dyn Expression>> = vec![];
+    let mut array_data_type = DataType::Any;
+    while *position < tokens.len() && tokens[*position].kind != TokenKind::RightBracket {
+        let value = parse_expression(context, env, tokens, position)?;
+        let value_type = value.expr_type(env);
+        if value_type != array_data_type {
+            return Err(Diagnostic::error("Expect Array values to have same types")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+        }
+
+        array_data_type = value_type;
+        array_values.push(value);
+
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::Comma {
+            *position += 1;
+        } else {
+            break;
+        }
+    }
+
+    // Make sure Array values end with by ]
+    if *position >= tokens.len() || tokens[*position].kind != TokenKind::RightBracket {
+        return Err(Diagnostic::error("Expect `]` at the end of array values")
+            .with_location(get_safe_location(tokens, *position))
+            .add_help("Try to add ']' at the end of array values")
+            .as_boxed());
+    }
+
+    // Consume Right Bracket `]`
+    *position += 1;
+
+    Ok(Box::new(ArrayExpression {
+        values: array_values,
+        element_type: array_data_type,
+    }))
+}
+
 fn parse_group_expression(
     context: &mut ParserContext,
     env: &mut Environment,
