@@ -1,5 +1,6 @@
 #[derive(PartialEq)]
 pub enum TokenKind {
+    Do,
     Set,
     Select,
     Distinct,
@@ -40,8 +41,14 @@ pub enum TokenKind {
 
     As,
 
+    /// Left parenthesis `(`
     LeftParen,
+    /// Right parenthesis `)`
     RightParen,
+    /// Left bracket `[`
+    LeftBracket,
+    /// Right bracket `]`
+    RightBracket,
 
     LogicalOr,
     LogicalAnd,
@@ -57,11 +64,13 @@ pub enum TokenKind {
     Integer,
     Float,
     String,
+    Array,
 
     True,
     False,
     Null,
 
+    Colon,
     ColonEqual,
 
     Plus,
@@ -514,14 +523,14 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
             continue;
         }
 
-        // Colon Equal
+        // Colon or Colon Equal
         if char == ':' {
-            if position + 1 < len && characters[position + 1] == '=' {
-                let location = Location {
-                    start: column_start,
-                    end: position,
-                };
+            let location = Location {
+                start: column_start,
+                end: position,
+            };
 
+            if position + 1 < len && characters[position + 1] == '=' {
                 let token = Token {
                     location,
                     kind: TokenKind::ColonEqual,
@@ -533,10 +542,15 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
                 continue;
             }
 
-            return Err(Diagnostic::error("Expect `=` after `:`")
-                .add_help("Only token that has `:` is `:=` so make sure you add `=` after `:`")
-                .with_location_span(column_start, position)
-                .as_boxed());
+            let token = Token {
+                location,
+                kind: TokenKind::Colon,
+                literal: ":".to_owned(),
+            };
+
+            tokens.push(token);
+            position += 1;
+            continue;
         }
 
         // Bang or Bang Equal
@@ -603,6 +617,42 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
             continue;
         }
 
+        // Left Bracket
+        if char == '[' {
+            let location = Location {
+                start: column_start,
+                end: position,
+            };
+
+            let token = Token {
+                location,
+                kind: TokenKind::LeftBracket,
+                literal: "[".to_owned(),
+            };
+
+            tokens.push(token);
+            position += 1;
+            continue;
+        }
+
+        // Right Bracket
+        if char == ']' {
+            let location = Location {
+                start: column_start,
+                end: position,
+            };
+
+            let token = Token {
+                location,
+                kind: TokenKind::RightBracket,
+                literal: "]".to_owned(),
+            };
+
+            tokens.push(token);
+            position += 1;
+            continue;
+        }
+
         // Semicolon
         if char == ';' {
             let location = Location {
@@ -1005,6 +1055,7 @@ fn ignore_c_style_comment(chars: &[char], pos: &mut usize) -> Result<(), Box<Dia
 fn resolve_symbol_kind(literal: String) -> TokenKind {
     match literal.to_lowercase().as_str() {
         // Reserved keywords
+        "do" => TokenKind::Do,
         "set" => TokenKind::Set,
         "select" => TokenKind::Select,
         "distinct" => TokenKind::Distinct,
@@ -1045,8 +1096,12 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "false" => TokenKind::False,
         "null" => TokenKind::Null,
 
+        // As for alias
         "as" => TokenKind::As,
 
+        // Array data type
+        "array" => TokenKind::Array,
+
         // Order by DES and ASC
         "asc" => TokenKind::Ascending,
         "desc" => TokenKind::Descending,
