@@ -3,6 +3,7 @@ use gitql_ast::expression::ExpressionKind;
 use gitql_ast::expression::StringExpression;
 use gitql_ast::expression::StringValueType;
 use gitql_core::environment::Environment;
+use gitql_core::signature::Signature;
 use gitql_core::types::DataType;
 
 use crate::diagnostic::Diagnostic;
@@ -497,3 +498,66 @@ pub fn type_check_selected_fields(
     }
     Ok(())
 }
+
+/// Check that all projection columns are valid for this table name
+/// Return a Diagnostic Error if anything is wrong
+pub fn type_check_projection_symbols(
+    env: &mut Environment,
+    table_name: &str,
+    projection_names: &[String],
+    projection_locations: &[Location],
+) -> Result<(), Box<Diagnostic>> {
+    if table_name.is_empty() && !projection_names.is_empty() {
+        return Err(Diagnostic::error(&format!(
+            "Unresolved field with name `{}`",
+            projection_names[0]
+        ))
+        .with_location(projection_locations[0])
+        .as_boxed());
+    }
+
+    if table_name.is_empty() {
+        return Ok(());
+    }
+
+    let count = projection_names.len();
+    let table_fields = &env.schema.tables_fields_names[table_name];
+    for i in 0..count {
+        if !table_fields.contains(&projection_names[i].as_str()) {
+            return Err(Diagnostic::error(&format!(
+                "Table {} has no field with name `{}`",
+                table_name, projection_names[i]
+            ))
+            .add_help("Check the documentations to see available fields for each tables")
+            .with_location(projection_locations[i])
+            .as_boxed());
+        }
+    }
+
+    Ok(())
+}
+
+/// Resolve the return type of Std or Aggregation function and re resolve it if it variant or dynamic
+pub fn resolve_call_expression_return_type(
+    env: &Environment,
+    signature: &Signature,
+    arguments: &Vec<Box<dyn Expression>>,
+) -> DataType {
+    let mut return_type = signature.return_type.clone();
+
+    if let DataType::Dynamic(calculate_type) = return_type {
+        return_type = calculate_type(&signature.parameters);
+
+        // In Case that return type is variant for example [Int | Float] need to resolve it from arguments types
+        // To be able to use it with other expressions
+        if !arguments.is_empty() && return_type.is_variant() {
+            let mut arguments_types = Vec::with_capacity(arguments.len());
+            for argument in arguments {
+                arguments_types.push(argument.expr_type(env));
+            }
+            return_type = calculate_type(&arguments_types);
+        }
+    }
+
+    return_type
+}
