@@ -1,9 +1,10 @@
-use gitql_ast::types::DataType;
-use lazy_static::lazy_static;
+use gitql_core::types::DataType;
 use std::collections::HashMap;
+use std::sync::OnceLock;
 
-lazy_static! {
-    pub static ref TABLES_FIELDS_TYPES: HashMap<&'static str, DataType> = {
+pub fn tables_fields_types() -> &'static HashMap<&'static str, DataType> {
+    static HASHMAP: OnceLock<HashMap<&'static str, DataType>> = OnceLock::new();
+    HASHMAP.get_or_init(|| {
         let mut map = HashMap::new();
         map.insert("commit_id", DataType::Text);
         map.insert("title", DataType::Text);
@@ -22,11 +23,12 @@ lazy_static! {
         map.insert("updated", DataType::DateTime);
         map.insert("repo", DataType::Text);
         map
-    };
+    })
 }
 
-lazy_static! {
-    pub static ref TABLES_FIELDS_NAMES: HashMap<&'static str, Vec<&'static str>> = {
+pub fn tables_fields_names() -> &'static HashMap<&'static str, Vec<&'static str>> {
+    static HASHMAP: OnceLock<HashMap<&'static str, Vec<&'static str>>> = OnceLock::new();
+    HASHMAP.get_or_init(|| {
         let mut map = HashMap::new();
         map.insert("refs", vec!["name", "full_name", "type", "repo"]);
         map.insert(
@@ -66,5 +68,5 @@ lazy_static! {
         );
         map.insert("tags", vec!["name", "repo"]);
         map
-    };
+    })
 }
